@@ -46,7 +46,7 @@ from jsonpointer import JsonPointer, JsonPointerException
 
 # Will be parsed by setup.py to determine package metadata
 __author__ = 'Stefan Kögl <stefan@skoegl.net>'
-__version__ = '1.5'
+__version__ = '1.6'
 __website__ = 'https://github.com/stefankoegl/python-json-patch'
 __license__ = 'Modified BSD License'
 
@@ -308,7 +308,7 @@ class JsonPatch(object):
         def compare_lists(path, src, dst):
             return _compare_lists(path, src, dst)
 
-        return cls(list(compare_dicts([], src, dst)))
+        return cls(list(compare_values([], src, dst)))
 
     def to_string(self):
         """Returns patch set as JSON string."""
@@ -387,7 +387,8 @@ class RemoveOperation(PatchOperation):
         try:
             del subobj[part]
         except (KeyError, IndexError) as ex:
-            raise JsonPatchConflict(str(ex))
+            msg = "can't remove non-existent object '{0}'".format(part)
+            raise JsonPatchConflict(msg)
 
         return obj
 
